<h1 align = "center">:rocket: Embeddings :facepunch:</h1>

---
## [word2vec][1]
## [doc2vec][2]



# Unsupervised sentence embedding models
- Word mover's distance: [paper](http://proceedings.mlr.press/v37/kusnerb15.pdf), [gensim example](https://markroxor.github.io/gensim/static/notebooks/WMD_tutorial.html)
- [Extension of BOW based on word2vec](https://www.zhihu.com/question/29978268/answer/55338644): The sentence vector contains top 10 word vector similarity between each word of the sentence and the vocabulary.
- [LSTM + AutoEncoder](https://www.zhihu.com/question/29978268/answer/114093723)
- [SIF](https://github.com/gaoisbest/NLP-Projects/blob/master/Text%20similarity/SIF.py)
- [Mean word vectors](https://github.com/gaoisbest/NLP-Projects/blob/master/Text%20similarity/Word2vec_mean.py)
- [Doc2vec](https://github.com/gaoisbest/NLP-Projects/blob/master/Text%20similarity/Doc2vec_model.py)
- [LDA](https://github.com/gaoisbest/NLP-Projects/blob/master/Text%20similarity/LDA_model.py)
- [LSI](https://github.com/gaoisbest/NLP-Projects/blob/master/Text%20similarity/LSI_model.py)
- [Sent2vec](https://github.com/epfml/sent2vec)

# Sentence encoder example
- https://hanxiao.github.io/2018/06/25/4-Encoding-Blocks-You-Need-to-Know-Besides-LSTM-RNN-in-Tensorflow/?from=timeline&isappinstalled=0


---
[2]: https://github.com/Jie-Yuan/text2vec
